continuous_example: Mock RCT data with a continuous endpoint

continuous_exampleR Documentation

Mock RCT data with a continuous endpoint

Description

A list with two objects (a) X, a dataframe with n rows representing clinical subjects and columns: treatment, x1, x2, x3, x4 and x5 where treatment is binary indicating the two arms of the clinical trial and x1, ..., x5 are covariates that were collected about each subject and (b) y, a length n vector storing the continuous response values where, in this mock dataset, larger values indicate "better" outcomes for the subjects.

Author(s)

My Name kapelner@qc.cuny.edu


PTE documentation built on July 27, 2026, 9:12 a.m.

Related to continuous_example in PTE...