Learn R Programming

PTE (version 2.0)

print.PTE_bootstrap_results: Prints a summary of the model to the console

Description

Prints a summary of the model to the console

Usage

# S3 method for PTE_bootstrap_results
print(x, ...)

Arguments

x

A PTE_bootstrap_results model object built via running the PTE_bootstrap_inference function.

...

Other methods passed to print

Author

Adam Kapelner

Examples

Run this code
library(PTE)
data(continuous_example)
pte_results = PTE_bootstrap_inference(continuous_example$X, continuous_example$y,
    regression_type = "continuous", B = 5, num_cores = 1)
print(pte_results)

Run the code above in your browser using DataLab