summary.PTE_bootstrap_results: Prints a summary of the model to the console

View source: R/plot_and_summarize.R

summary.PTE_bootstrap_resultsR Documentation

Prints a summary of the model to the console

Description

Prints a summary of the model to the console

Usage

## S3 method for class 'PTE_bootstrap_results'
summary(object, ...)

Arguments

object

A PTE_bootstrap_results model object built via running the PTE_bootstrap_inference function.

...

Other methods passed to summary

Author(s)

Adam Kapelner

Examples

library(PTE)
data(continuous_example)
pte_results = PTE_bootstrap_inference(continuous_example$X, continuous_example$y,
    regression_type = "continuous", B = 5, num_cores = 1)
summary(pte_results)


PTE documentation built on July 27, 2026, 9:12 a.m.