print.PTE_bootstrap_results: Prints a summary of the model to the console
Description
Prints a summary of the model to the console
Usage
# S3 method for PTE_bootstrap_results
print(x, ...)
Arguments
- x
A PTE_bootstrap_results model object built via
running the PTE_bootstrap_inference function.
- ...
Other methods passed to print